@@ -502,7 +502,7 @@ class WordType(caching.base.CachingMixin,models.Model):
         return fwnd
 
     def getPhonoProb(self,subset='all',speaker=None,dialog=None):
-        if self.SPhonoProb is not None and self.BiPhonoProb is not None:
+        if subset == 'all' and self.SPhonoProb is not None and self.BiPhonoProb is not None:
             return self.SPhonoProb,self.BiPhonoProb
         any_segment = '[A-Za-z]{1,2}'
         patterns = []
@@ -530,10 +530,10 @@ class WordType(caching.base.CachingMixin,models.Model):
                 totPattern = '^'+' '.join([any_segment] * (i+2)) +'.*$'
                 count = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     where = [UR_LOOKUP],
-                    params = [pattern]).count()
+                    params = [pattern])
                 totCount = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     where = [UR_LOOKUP],
-                    params = [totPattern]).count()
+                    params = [totPattern])
                 BPprob += float(sum([x.getFreq(subset=subset,speaker=speaker,dialog=dialog)
                                 for x in count])) / float(sum([x.getFreq(subset=subset,speaker=speaker,dialog=dialog)
                                                                     for x in totCount]))
